@@ -41,11 +41,11 @@ class LocaleContext(object):
             except Exception, ex:
                 raise ValueError("locale")
 
-    def from_now(self, datetime_or_timestamp, precision=1):
-        if isinstance(datetime_or_timestamp, datetime.datetime):
-            value = datetime
+    def from_now(self, time, precision=1, fromUTC=False):
+        if isinstance(time, datetime.datetime):
+            value = time
         else:
-            value = datetime.datetime.fromtimestamp(float(datetime_or_timestamp))
+            value = (datetime.datetime.utcfromtimestamp if fromUTC else datetime.datetime.fromtimestamp)(float(time))
 
         now = datetime.datetime.now()
         ago = now > value
@@ -74,8 +74,8 @@ def set_locale(locale):
     _locale.set_locale(locale)
 
 
-def from_now(datetime_or_timestamp, precision=1):
-    return _locale.from_now(datetime_or_timestamp, precision=precision)
+def from_now(datetime_or_timestamp, precision=1, fromUTC=False):
+    return _locale.from_now(datetime_or_timestamp, precision=precision, fromUTC=fromUTC)
 
 
 if "__main__" == __name__:
